@@ -29,7 +29,7 @@ from Products.CMFCore.utils import getToolByName
 
 import zLOG
 from config import SEPARATOR, PROPS, ALLPROPS, NONATPROPS, TYPEMAP
-
+from Globals import DTMLFile
 
 class ContentExporter(UniqueObject, SimpleItem):
     """An old school Product for plone 2 that sucks out content into plone 3
@@ -196,23 +196,22 @@ class ContentExporter(UniqueObject, SimpleItem):
                 #if obj:
                 #    self.write_file(path,'%s.jpg' % user_id,obj.data)
 
-        info = {'title': 'source_users',
-                'users': user_info,
-               }
-        template = PageTemplateFile(os.path.join('xml','zodbusers.xml'),
-                                    globals()).__of__(portal)
-        self.write_file('/acl_users','source_users.xml', template(info=info))
-
-        template = PageTemplateFile(os.path.join('xml','zodbroles.xml'),
-                                    globals()).__of__(portal)
+        info = {}
+        info['title'] = 'source_users'
+        info['users'] = user_info
+        template = DTMLFile(os.path.join('xml','zodbusers.xml'),
+                            globals()).__of__(portal) 
+        self.write_file('/acl_users','source_users.xml', template(options=info))
+        template = DTMLFile(os.path.join('xml','zodbroles.xml'),
+                            globals()).__of__(portal) 
         info = self._getRoleInfo(portal)
         self.write_file('/acl_users','portal_role_manager.xml',
-                                            template(info=info))
-        template = PageTemplateFile(os.path.join('xml','zodbgroups.xml'),
-                                    globals()).__of__(portal)
+                                            template(options=info))
+        template = DTMLFile(os.path.join('xml','zodbgroups.xml'),
+                            globals()).__of__(portal) 
         info = self._getGroupInfo(portal)
         self.write_file('/acl_users','source_groups.xml',
-                                     template(info=info))
+                                     template(options=info))
         output = ostream.getvalue()
         # strip Windows line endings
         if hasattr(os, 'O_BINARY'):
@@ -343,8 +342,10 @@ class ContentExporter(UniqueObject, SimpleItem):
             return
 
         if users:
-            portal.REQUEST = request    
-            self.export_users(portal)
+            if hasattr(portal,'REQUEST'):
+                self.export_users(portal)
+            else:
+                self.out.append('Sorry users couldnt be exported because a REQUEST object is needed')
 
         if not root.startswith('/'):
             root = '/%s' % root
