@@ -22,9 +22,13 @@ class ContentExporterView(BrowserView, ContentExporter):
         """ use the root form value to flag run export """
         request = getattr(self,'REQUEST',{})
         root = request.get('root','')
+        users = request.get('exportusers',None)
         if root:
             self.out = []
-            self.export(root=root, portal=getUtility(ISiteRoot))
+            self.export(root=root,
+                        portal=getUtility(ISiteRoot),
+                        users=users,
+                        request=request)
         return xhtml_compress(self._template())
 
     def getLog(self):
