@@ -31,7 +31,7 @@ from ilrt.contentmigrator.exportimport.content import importSiteStructure
 from ilrt.contentmigrator.ContentMigrator.config import SEPARATOR, PROPS, ALLPROPS
 
 MIGRATOR_TOOL_TYPE = "Content Migrator Tool"
-MIGRATOR_TOOL_ID = "portal_contentsetup"
+MIGRATOR_TOOL_ID = "portal_setupcontent"
 
 class ContentMigratorView(BrowserView):
     ''' This allows for zcml config of the management screens for the tool '''
