@@ -256,7 +256,7 @@ class SFWA(StructureFolderWalkingAdapter):
                     self.put_props(obj, meta, import_context, subdir)
 
         if getattr(self,'reindex','item') == 'item':
-            obj.reindexObject()
+            obj.indexObject()
 
         return obj
 
