@@ -30,9 +30,9 @@ def dodatetime(value):
         try:
             return DateTime(value)
         except:
-            return DateTime()
+            return None
     else:
-        return DateTime()
+        return None
     
 def dotext(value):
     value = str(value).replace("\r", "")
@@ -41,7 +41,7 @@ def dotext(value):
     return value.replace(SEPARATOR,"\n")
 
 def dolines(value):
-    return value.split(SEPARATOR)
+    return value.split("\n")
 
 atconvert = {'computed':dummy, 'text':dotext, 'string':dotext, 
              'boolean':doboolean,'datetime':dodatetime,'lines':dolines,
